@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 Canonical Ltd
+# Copyright (C) 2006, 2007, 2009, 2010 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 """Command which looks for unsigned commits by the current user, and signs them.
 """
@@ -30,7 +30,7 @@ from bzrlib.option import Option
 
 
 class cmd_sign_my_commits(Command):
-    """Sign all commits by a given committer.
+    __doc__ = """Sign all commits by a given committer.
 
     If location is not specified the local tree is used.
     If committer is not specified the default committer is used.
