@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2008 Canonical Ltd
+# Copyright (C) 2005-2010 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@ from bzrlib import uncommit, workingtree
 from bzrlib.bzrdir import BzrDirMetaFormat1
 from bzrlib.errors import BzrError, BoundBranchOutOfDate
 from bzrlib.tests import TestCaseWithTransport
+from bzrlib.tests.script import ScriptRunner
 
 
 class TestUncommit(TestCaseWithTransport):
@@ -216,10 +217,17 @@ class TestUncommit(TestCaseWithTransport):
     def test_uncommit_shows_log_with_revision_id(self):
         wt = self.create_simple_tree()
 
-        out, err = self.run_bzr('uncommit --force', working_dir='tree')
-        self.assertContainsRe(out, r'second commit')
-        self.assertContainsRe(err, r'You can restore the old tip by running')
-        self.assertContainsRe(err, r'bzr pull . -r revid:a2')
+        script = ScriptRunner()
+        script.run_script(self, """
+$ cd tree
+$ bzr uncommit --force 
+    2 ...
+      second commit
+...
+The above revision(s) will be removed.
+You can restore the old tip by running:
+  bzr pull . -r revid:a2
+""")
 
     def test_uncommit_octopus_merge(self):
         # Check that uncommit keeps the pending merges in the same order
